==> mybody_api_client-0.5.18.tar.gz: mybody_api_client-0.5.18/mybody_api_client/routes/client/promocodes/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute
from mybody_api_client.utils import RequestTypes


class ClientPromocodeRoute(BaseRoute):
    prefix = '/promocodes'

    async def get(
            self,
            id_str: str,
    ):
        return await self.request(
            type_=RequestTypes.GET,
            prefix='/get',
            parameters={
                'id_str': id_str,
            },
            token_required=False,
            response_key='promocode',
        )

    async def check(
            self,
            id_str: str,
            currency: str,
            service_cost_id: int,
    ):
        return await self.request(
            type_=RequestTypes.GET,
            prefix='/check',
            parameters={
                'id_str': id_str,
                'currency': currency,
                'service_cost_id': service_cost_id,
            },
        )

==> mybody_api_client-0.5.21.tar.gz: mybody_api_client-0.5.21/mybody_api_client/routes/client/promocodes/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute
from mybody_api_client.utils import RequestTypes


class ClientPromocodeRoute(BaseRoute):
    _prefix = '/promocodes'

    async def get(
            self,
            id_str: str,
    ):
        return await self._request(
            type_=RequestTypes.GET,
            prefix='/get',
            parameters={
                'id_str': id_str,
            },
            token_required=False,
            response_key='promocode',
        )

    async def check(
            self,
            id_str: str,
            currency: str,
            service_cost_id: int,
    ):
        return await self._request(
            type_=RequestTypes.GET,
            prefix='/check',
            parameters={
                'id_str': id_str,
                'currency': currency,
                'service_cost_id': service_cost_id,
            },
        )
